@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2024 the Eask authors.
+ * Copyright (C) 2022-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,6 @@
 
 "use strict";
 
-const path = require('path');
-const fs = require('fs');
-const readline = require('readline');
-
 exports.command = ['init [files..]'];
 exports.desc = 'Initialize project to use Eask';
 exports.builder = yargs => yargs
