@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2023-2025 the Eask authors.
+ * Copyright (C) 2023-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['source <type>'];
-exports.desc = UTIL.hide_cmd('Add/Remove source from DSL');
+exports.desc = UTIL.hide_cmd('Manage sources');
 exports.builder = function (yargs) {
   yargs.usage(`${exports.desc}
 
@@ -30,8 +30,8 @@ Usage: eask source <type> [options..]`)
   if (UTIL.cmd_count() == 1) {
     yargs.positional(
       '<type>', {
-      description: 'type of the control',
-    });
+        description: 'type of the control',
+      });
   }
 }
 
