@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2024 the Eask authors.
+ * Copyright (C) 2022-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['uninstall [names..]', 'delete [names..]'];
-exports.desc = 'Uninstall packages';
+exports.desc = 'Uninstall packages from archives';
 exports.builder = yargs => yargs
   .positional(
     '[names..]', {
