@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2023-2025 the Eask authors.
+ * Copyright (C) 2023-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['gitlab [file]', 'gitlab-runner [file]'];
-exports.desc = 'Generate GitLab Runner workflow yaml file';
+exports.desc = 'Generate the GitLab Runner workflow yaml file';
 exports.builder = yargs => yargs
   .positional(
     '[file]', {
